@@ -1,11 +1,11 @@
 from flask_monitoringdashboard.database import CodeLine
 
 
-def get_code_line(db_session, fn, ln, name, code):
+def get_code_line(session, fn, ln, name, code):
     """
     Get a CodeLine object from a given quadruple of fn, ln, name, code. If the CodeLine object
     doesn't already exist, a new one is created in the database.
-    :param db_session: session for the database
+    :param session: session for the database
     :param fn: filename (string)
     :param ln: line_number of the code (int)
     :param name: function name (string)
@@ -13,7 +13,7 @@ def get_code_line(db_session, fn, ln, name, code):
     :return: a CodeLine object
     """
     result = (
-        db_session.query(CodeLine)
+        session.query(CodeLine)
         .filter(
             CodeLine.filename == fn,
             CodeLine.line_number == ln,
@@ -24,7 +24,7 @@ def get_code_line(db_session, fn, ln, name, code):
     )
     if not result:
         result = CodeLine(filename=fn, line_number=ln, function_name=name, code=code)
-        db_session.add(result)
-        db_session.flush()
+        session.add(result)
+        session.flush()
 
     return result
