@@ -5,7 +5,7 @@
 from flask import render_template
 from flask.helpers import send_from_directory
 
-from flask_monitoringdashboard import loc, blueprint
+from flask_monitoringdashboard import loc, blueprint, config
 from flask_monitoringdashboard.core.auth import secure
 
 
@@ -23,4 +23,4 @@ def static(filename):
 @blueprint.route('/<path:path>')  # Catch-All URL: http://flask.pocoo.org/snippets/57/
 @secure
 def index(path):
-    return render_template('fmd_base.html')
+    return render_template('fmd_base.html', blueprint_name=config.blueprint_name)
